;@***h* SOLAR_IRRADIANCE_FCDR/add_background_component_to_irradiance_uncertainty.pro
;
; NAME
;   add_background_component_to_irradiance_uncertainty
;
; PURPOSE
;   The add_background_component_to_irradiance_uncertainty.pro adds the magnitude of the speculative background component to the irrradiance 
;   to the estimates of irradiance uncertainty.  
;   
; DESCRIPTION
;   The add_background_component_to_irradiance_uncertainty.pro differences the modeled irradiance computed from model inputs with background and 
;   cycle components from the modeled irradiance computed from model inputs with the cycle-only components.  It adds the absolute value to the 
;   estimates of irradiance uncertainty, which in standard processing are derived from the cycle-only variations alone.
;
; INPUTS
;   irradiance_data  - structure of the modeled irradiance (and uncertainties) from model inputs with background and cycle components
;   cycle_data       - structure of the modeled irradiance (and uncertainties) from model inputs with cycle components alone
;
; OUTPUTS
;   irradiance_data  - structure of the modeled irradiance from model inputs with background and cycle components, which contains 
;                      revised uncertainty estimate that includes the magnitude of the background irradiance component.
;
; AUTHOR
;   Odele Coddington, Laboratory for Atmospheric and Space Physics, Boulder, CO
;   Doug Lindholm, Laboratory for Atmospheric and Space Physics, Boulder, CO
;   Chris Lindholm, Laboratory for Atmospheric and Space Physics, Boulder, CO
;   Judith Lean, Space Science Division, Naval Research Laboratory, Washington, DC
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
;   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
;   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
;   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
;   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
;   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
;   SUPPORT TO USERS.
;
; REVISION HISTORY
;   07/29/2016 Initial Version prepared for NCDC
;
; USAGE
;   add_background_component_to_irradiance_uncertainty,irradiance_data,cycle_data
;
;@*****

function add_background_component_to_irradiance_uncertainty,irradiance_data,cycle_data

;compute magnitude of difference between irradiance data (with background+cycle) and irradiance data (with cycle only)
tsi_diff = abs(irradiance_data.tsi - cycle_data.tsi)
ssi_diff = abs(irradiance_data.ssi - cycle_data.ssi)

;Replace the cycle-only irradiance uncertainty in the irradiance_data with the sum of this cycle-only component and the absolute magnitude of the difference in irradiance attributed to the background component (i.e. the speculative background component is considered to all be uncertain)
irradiance_data.tsiunc = cycle_data.tsiunc + tsi_diff
irradiance_data.ssiunc = cycle_data.ssiunc + ssi_diff

return, irradiance_data
end