;@***h* SOLAR_IRRADIANCE_FCDR/get_checksum.pro
;
; NAME
;   get_checksum
;
; PURPOSE
;   Computes the md5 checksum of a file.
;
; DESCRIPTION
;   Computes the md5 checksum of a file.
;
; INPUTS
;   file - path to a file
;
; OUTPUTS
;   md5 - md5 checksum of given file
;
; AUTHOR
;   Odele Coddington, Laboratory for Atmospheric and Space Physics, Boulder, CO
;   Doug Lindholm, Laboratory for Atmospheric and Space Physics, Boulder, CO
;   Chris Lindholm, Laboratory for Atmospheric and Space Physics, Boulder, CO
;   Judith Lean, Space Science Division, Naval Research Laboratory, Washington, DC
;
; COPYRIGHT
;   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC
;   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE
;   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS
;   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY,
;   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND
;   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
;   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL
;   SUPPORT TO USERS.
;
; REVISION HISTORY
;   01/06/2017 Updated Robodoc header for v02r01 source code release.
;
; USAGE
;   md5 = get_checksum(file)
;
;@*****

function get_checksum, file
  ;Perform MD5 checksum on the given file
  ;The system command depends on OS
  os = !Version.OS
  if (os eq 'linux')  then begin 
    command = 'md5sum ' + file + " | awk '{print $1}'" 
    spawn,command,checksum
  endif else if (os eq 'darwin') then begin
    command = 'md5 ' + file + " | awk '{print $4}'"
    spawn,command,checksum
  endif
 
  return, checksum[0]
end
